@@ -1,10 +1,9 @@
 use std::fs::{DirEntry};
-use std::io::{Error,ErrorKind};
-
+use crate::BrownError;
 
 /// The get_file_name takes a DirEntry and return its file name with out the extentions.
-pub fn get_file_name(dir_entry:&DirEntry)->Result<String,Error>{
-    let e = Error::new(ErrorKind::NotFound, "could not extract file name (stem)");
+pub fn get_file_name(dir_entry:&DirEntry)->Result<String,BrownError>{
+    let e = BrownError::FileNameError;
     let path = dir_entry.path();
         match path.file_stem() {
             Some(file_stem_osstr)=>{
