@@ -1,10 +1,12 @@
 mod setup;
 use brown as bro;
+
 #[cfg(test)]
 #[test]
 fn loop_test(){
 let _ = setup::build_up_dirs();
-let output = bro::copy_dir_structure
+// let j = bro::
+let output = bro::clone_dir_structure
 (setup::PARENTFOLDER,"tests/abc/").unwrap();
 // let _ = setup::tear_down();
 println!("{:#?}",output);
